======
pydong
======


.. image:: https://img.shields.io/pypi/v/pydong.svg
        :target: https://pypi.python.org/pypi/pydong

.. image:: https://img.shields.io/travis/lipidong/pydong.svg
        :target: https://travis-ci.com/lipidong/pydong

.. image:: https://readthedocs.org/projects/pydong/badge/?version=latest
        :target: https://pydong.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




pidong's python tool


* Free software: MIT license
* Documentation: https://pydong.readthedocs.io.


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
